# ngs_tools
![github version](https://img.shields.io/badge/Version-1.1.2-informational)
[![pypi version](https://img.shields.io/pypi/v/ngs-tools)](https://pypi.org/project/ngs-tools/1.1.2/)
![python versions](https://img.shields.io/pypi/pyversions/ngs-tools)
![status](https://github.com/Lioscro/ngs-tools/workflows/CI/badge.svg)
[![codecov](https://codecov.io/gh/Lioscro/ngs-tools/branch/main/graph/badge.svg?token=CITIPF64QZ)](https://codecov.io/gh/Lioscro/ngs-tools)
[![docs](https://readthedocs.org/projects/ngs-tools/badge/?version=latest)](https://ngs-tools.readthedocs.io/en/latest/?badge=latest)
[![license](https://img.shields.io/pypi/l/ngs-tools)](LICENSE)

Reusable tools for working with next-generation sequencing (NGS) data

Documentation: https://ngs-tools.readthedocs.io/en/latest/
